aboutsummaryrefslogtreecommitdiff
path: root/views
diff options
context:
space:
mode:
authorEvan Winslow <evan.b.winslow@gmail.com>2010-07-16 23:49:54 +0000
committerEvan Winslow <evan.b.winslow@gmail.com>2010-07-16 23:49:54 +0000
commitc7cab3a3bde627d52d94b4d99dd7372d85759c53 (patch)
tree18ea9b00f60d4bfe57785d563ea34aa778446f13 /views
parent8913932d656671e64aa6f63a77f9b364011816d8 (diff)
downloadelgg-c7cab3a3bde627d52d94b4d99dd7372d85759c53.tar.gz
elgg-c7cab3a3bde627d52d94b4d99dd7372d85759c53.tar.bz2
HTML5 plugin no longer uses custom page_elements/head view
Diffstat (limited to 'views')
-rw-r--r--views/default/page_elements/header.php76
1 files changed, 71 insertions, 5 deletions
diff --git a/views/default/page_elements/header.php b/views/default/page_elements/header.php
index 13e2f6e01..a69f79cba 100644
--- a/views/default/page_elements/header.php
+++ b/views/default/page_elements/header.php
@@ -1,21 +1,87 @@
<?php
/**
* HTML5 header
* The standard HTML5 header that displays across the site
*
* @package Elgg
* @subpackage Core
* @author Curverider Ltd
* @link http://elgg.org/
*
+ * @uses $vars['config'] The site configuration settings, imported
+ * @uses $vars['title'] The page title
+ * @uses $vars['body'] The main content of the page
*/
+// Set title
+if (empty($vars['title'])) {
+ $title = $vars['config']->sitename;
+} else if (empty($vars['config']->sitename)) {
+ $title = $vars['title'];
+} else {
+ $title = $vars['config']->sitename . ": " . $vars['title'];
+}
+
+global $autofeed;
+if (isset($autofeed) && $autofeed == true) {
+ $url = $url2 = full_url();
+ if (substr_count($url,'?')) {
+ $url .= "&view=rss";
+ } else {
+ $url .= "?view=rss";
+ }
+ if (substr_count($url2,'?')) {
+ $url2 .= "&view=odd";
+ } else {
+ $url2 .= "?view=opendd";
+ }
+ $feedref = <<<END
+
+ <link rel="alternate" type="application/rss+xml" title="RSS" href="{$url}" />
+ <link rel="alternate" type="application/odd+xml" title="OpenDD" href="{$url2}" />
+
+END;
+} else {
+ $feedref = "";
+}
+
// we won't trust server configuration but specify utf-8
header('Content-type: text/html; charset=utf-8');
+$version = get_version();
+$release = get_version(true);
?>
-
<!doctype html>
<html>
-<?php echo elgg_view('page_elements/head', $vars); ?>
-<body> \ No newline at end of file
+<head>
+ <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+ <meta name="ElggRelease" content="<?php echo $release; ?>" />
+ <meta name="ElggVersion" content="<?php echo $version; ?>" />
+ <title><?php echo $title; ?></title>
+
+ <!-- include the default css file -->
+ <link rel="stylesheet" href="<?php echo $vars['url']; ?>_css/css.css?lastcache=<?php echo $vars['config']->lastcache; ?>&amp;viewtype=<?php echo $vars['view']; ?>" type="text/css" />
+
+ <script type="text/javascript" src="<?php echo $vars['url']; ?>vendors/jquery/jquery-1.3.2.min.js"></script>
+ <script type="text/javascript" src="<?php echo $vars['url']; ?>vendors/jquery/jquery-ui-1.7.2.custom.min.js"></script>
+ <script type="text/javascript" src="<?php echo $vars['url']; ?>vendors/jquery/jquery.form.js"></script>
+ <script type="text/javascript" src="<?php echo $vars['url']; ?>_css/js.php?lastcache=<?php echo $vars['config']->lastcache; ?>&amp;js=initialise_elgg&amp;viewtype=<?php echo $vars['view']; ?>"></script>
+
+<?php
+ global $pickerinuse;
+ if (isset($pickerinuse) && $pickerinuse == true) {
+?>
+ <!-- only needed on pages where we have friends collections and/or the friends picker -->
+ <script type="text/javascript" src="<?php echo $vars['url']; ?>vendors/jquery/jquery.easing.1.3.packed.js"></script>
+ <script type="text/javascript" src="<?php echo $vars['url']; ?>_css/js.php?lastcache=<?php echo $vars['config']->lastcache; ?>&amp;js=friendsPickerv1&amp;viewtype=<?php echo $vars['view']; ?>"></script>
+<?php
+ }
+?>
+
+ <?php
+ echo $feedref;
+ echo elgg_view('metatags',$vars);
+ ?>
+</head>
+
+<body>
@@ -1,21 +1,87 @@
<?php
/**
- * HTML5 header
- * The standard HTML5 header that displays across the site
+ * Elgg pageshell
+ * The standard HTML header that displays across the site
*
* @package Elgg